cgexplore.topologies.M4L82
==========================

.. currentmodule:: cgexplore.topologies

.. autoclass:: M4L82
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~M4L82.paired_wall_1_coord
      ~M4L82.paired_wall_2_coord
      ~M4L82.wall_1_shift
      ~M4L82.wall_2_shift
   
   